@@ -14,5 +14,6 @@ table! {
         description -> Text,
     }
 }
-
+joinable!(metrics -> metric_keys (metric_key_id));
+allow_tables_to_appear_in_same_query!(metrics, metric_keys);
 // allow_tables_to_appear_in_same_query!(counters,);
